# **Mobroute**: Available GTFS Feeds

## **Contents:**

- *1:* [Overview](#strongoverviewstrong)
- *2:* [Finding GTFS Feed IDs: CI-Tested Feeds / Routes](#strongfinding-gtfs-feed-idsstrong-ci-tested-feeds--routes)
- *3:* [Finding GTFS Feed IDs: Browsable Mobility Database Source Catalog UI](#strongfinding-gtfs-feed-idsstrong-browsable-mobility-database-source-catalog-ui)
- *4:* [Finding GTFS Feed IDs: User-Reported Known Good & Problematic Feeds](#strongfinding-gtfs-feed-idsstrong-user-reported-known-good-amp-problematic-feeds)

## **Overview**

In terms of user configuration, determining which GTFS feed IDs you'd like
to use is an essential component of using Mobroute. Mobroute's GTFS feed
IDs correlate to [Mobility Database](https://database.mobilitydata.org/)'s
MDBID ([Mobility Database source
ID](https://github.com/MobilityData/mobility-database-catalogs?tab=readme-ov-file#gtfs-schedule-schema)).
Using these MDBIDs / feed IDs allows Mobroute to uniquely map each single
GTFS feed ID number to a source agency ZIP URL for each. This frees the
end-user from manually sourcing GTFS ZIP URLs, downloading the relevant
data, and manging this data. Rather from Mobroute's side you simply
specify the GTFS Feed ID number(s) to use for routing requests and
Mobroute takes care of the rest (from pulling the correct GTFS archive
as specified by the Mobility Database, automating the import process,
updating when necessary, etc.)

To determine which feed IDs you can use there are a few different options
which are elaborated on below.

## **Finding GTFS Feed IDs:** CI-Tested Feeds / Routes

> [CI-Tested Feeds / Routes Page](https://ci.lrdu.org/tests_results/)

The first choice in picking which GTFS Feed IDs (MDBID) you should use
for routing requests should be to reference the [routing API's automated
test results page](https://ci.lrdu.org/tests_results/).  This page is
automated generated through continuous integration and this CI is run
with every change to Mobroute's codebase. As such, the feeds in this
list are essentially "known good" & "tested" feeds in that these feeds
were tested against in development. Ofcourse this is a quite small list
in comparison with the potential 1000s of feeds in the Mobility Database.


## **Finding GTFS Feed IDs:** Browsable Mobility Database Source Catalog UI

> [Browsable Mobility Database Source Catalog UI](https://mdb.lrdu.org/)

The second choice in picking which GTFS Feed IDs (MDBID) you
should use for routing requests is to reference the [Mobility
Database](https://database.mobilitydata.org/) itself. Since the Mobility
Database distributes its data a CSV which may be unweildly, the [Browsable
Mobility Database Source Catalog UI](http://mdb.lrdu.org) can be used
to quickly search & find potential GTFS feeds to test.

Mobroute is potentially compatible with any/all GTFS feeds in this UI,
However, unfortunately, not all sources are valid GTFS and some feeds
are outdated, invalid GTFS, and similar. This UI flags feeds which
are known as active versus not. You should aim to use active feeds or
CI-tested feeds.

## **Finding GTFS Feed IDs:** User-Reported Known Good & Problematic Feeds

> [User-Reported Known Good & Problematic Feeds Ticket](https://todo.sr.ht/~mil/mobroute-tickets/25)

Users of Mobroute & Transito are encouraged to report back (e.g. comment
on the ticket) GTFS feeds which work well and those that cause issues on
Mobroute's issue tracker. The [user-reported known good & problematic
feeds ticket](https://todo.sr.ht/~mil/mobroute-tickets/25) is an ongoing
tracking as such of feeds that both work well (yet have not been added to
CI yet) and feeds which fail to route properly and diagnostics. Posting
in this ticket will enable continual improvement of Mobroute by helping
flag & assess problems in the routing system with untested GTFS feeds.

---

> [All Mobroute Docs](http://sr.ht/~mil/mobroute)
