# **Known Limitations**

As the Mobroute project is a work in progress overall there are a
number of known defects and limitations to note. See the [roadmap
doc](doc/roadmap.md) for details on planned features and overall project
state. This list is in supplement to the roadmap in order to provide a
simple readable format of known limitations to set expectations if you
are trying Mobroute locally or using Transito on your mobile device.

- The SQLite database is stored uncompressed and the schema used is currently
  relatively unoptimized. Thus the DB size is several factors larger then it
  needs to be and devices with small storage capacities may struggle or fail
  in load.
- Large GTFS archive sources may fail or take a long time to load. Extracted 
  stop_times.txt up to ~200MB or so have been successfully tested locally
  and larger sources should work; but this is dependent on local resources.
- GTFS feeds not providing transfers.txt & multiple-GTFS feed requests, e.g.
  using generated transfers is relatively unoptimized and can be slow to load
  dependent on the threshold set for max_transfer_seconds; if you want to
  use multiple feeds or generated transfers quickly, set max_transfer_seconds
  to a lower value.
- GTFS sources with multiple agencies provided in the GTFS agency.txt table
  may not produce accurate routes as this is unaccounted for in loading.
- Routing requests currently do not work beyond the boundaries of a single
  day (thus requests just before midnight may produce invalid routes).
- Indexes are maintained during load and compute stages (thus producing
  much slower then possible import speeds); the more data you import into the
  system, likely the slower subsequent imports will be.
- The design of the routing runtime, first loading the data needed into memory
  and then executing the routing request needs to be rethought. CSA (the 
  routing algorithm) is quite fast; while the most costly piece of routing 
  is loading to memory the data needed (which is cachable/memoizable) but
  is currently not treated as cached and always runs for all requests on 
  the CLI & in Transito.
- As of 0.2, the stops and stoptimes commands are nonfunctional as formatting
  and the codebase as a whole was reworked; these commands will be added back
  in the future

---

> [All Mobroute Docs](http://sr.ht/~mil/mobroute)
