# **Mobroute:** CLI Userguide

[Mobroute](http://sr.ht/~mil/mobroute) is a general purpose FOSS public
transportation router (e.g. trip planner) Go library and CLI that works by
directly ingesting timetable (GTFS) data from transit agencies themselves
(sourced from the Mobility Database). For an overview of Mobroute's
functionality see [Mobroute's project page](http://sr.ht/~mil/mobroute).
This document is a guide on how to run Mobroute's CLI by compiling the
Go codebase and then running routing requests locally.

- *1:* [Primer Documentation](#strongprimer-documentationstrong)
- *2:* [Mobroute CLI: Install](#strongmobroute-cli-installstrong)
- *3:* [Mobroute CLI: usage](#strongmobroute-cli-usagestrong)
- *4:* [Mobroute CLI: route](#strongmobroute-cli-routestrong)
- *5:* [Mobroute CLI: stops](#strongmobroute-cli-stopsstrong)
- *6:* [Mobroute CLI: schedule](#strongmobroute-cli-schedulestrong)
- *7:* [Mobroute CLI: database](#strongmobroute-cli-databasestrong)
- *8:* [Mobroute CLI: databaseq](#strongmobroute-cli-databaseqstrong)
- *9:* [Further Resources & Documentation](#strongfurther-resources-amp-documentationstrong)

## **Primer Documentation**

- Before using Mobroute's CLI, please read the following documentation:
  - [Mobroute: Project Overview & Featureset](https://git.sr.ht/~mil/mobroute)
  - [Mobroute: Finding GTFS Feeds](https://git.sr.ht/~mil/mobroute/tree/master/doc/doc_gtfsfeeds.md)
  - [Mobroute: Algorithm Tunable Parameters](https://git.sr.ht/~mil/mobroute/tree/master/doc/doc_tunables.md)

## **Mobroute CLI: Install**

- Install via package:
  - On some distrobutions the Mobroute CLI has been packaged, if available
    this is the simplest installation method.
  - Distrobution packages:
    - Alpine Linux Testing: `apk add mobroute`


- Install from source:
  - If a package is not avilabale for your distrobution, building from source
    is simple using Go
  - Steps:
    - (1) Installation assumes Go (>=1.18)
    - (2) Clone the Mobroute repository:
      - `git clone http://git.sr.ht/~mil/mobroute`
    - (3) Build the `mobroute` binary:
      - `./build.sh`
    - (4) Install as:
      - `cp mobroute /usr/bin/`
## **Mobroute CLI: usage**
```
Usage of ./mobroute:
  mobroute [subcommand]

Description:
  Mobroute is a general purpose FOSS public transportation router (e.g. trip planner). See: http://sr.ht/~mil/mobroute

Subcommands:
  - route: Perform a GTFS-based routing request via to CSA algorithm calculation, and formatting 
  - stops: Query to determine stops near a specific geocoordinate based on GTFS data
  - schedule: Query departure schedule for specific stops based on GTFS data
  - database: Download, import, clear, and manage GTFS data in the SQLite database (run before: route, stops, or schedule)
  - databaseq: Query the SQLite database for status of loaded GTFS feeds
  - version: Display the version information for this release
```

## **Mobroute CLI: route**
```
Usage of ./mobroute route:

Description:
  The route subcommand allows you to perform routing calculations using the CSA algorithm (and is a passthrough to the underlying Mobroute library OneshotRoute function). All functionality from loading GTFS data (by feed id), to loading the required data to memory, to performing the routing calculation via the CSA algorithm, and finally to formatting the result in several formats is handled by this single CLI subcommand. 	

Flags: 
  -d string
    	Verbose debug categories: (i) Information (w) Warn (d) Debug (default "i")
  -dprof string
    	Write debug pprof CPU profile to file
  -h	Show this usage message
  -p string
    	
    	JSON Parameters for oneshot route subcommand, should be in format of: {"route_params": {"feed_ids": [516],...}}
    	
    	Required route parameters:
    	  - feed_ids: Array of integer feed IDs (MDBID) to use for routing requests (ex: [516, 510])
    	  - from: Array of two floats in lat, lon format (ex: [50.012338, 19.88192])
    	  - to: Array of two floats in lat, lon format (ex: [50.012338, 19.88192])
    	  - transfer_categories: Array of transfers categories to load - may include "f" for feed, "i" for implicit, "g" for generated (ex: ["f", "i"])
    	  - output_formats: Array of formats for the output may include - may include "legs", "geojson", "diagnostics", "mapurl", "request" (ex: ["legs", "geojson"])
    	
    	Optional route parameters:
    	  - time: Datetime string at which route should depart in RFC3339 format (default: current system time)
    	  - max_walk_seconds: Maximum seconds walking distance on start/end of trip to get to/from origin/destination stops (default: 1200)
    	  - max_trip_seconds: Maximum seconds the entire route/trip can take (default: 14400)
    	  - min_transfer_seconds: Minimum seconds each transfer in the route can take (default: 180)
    	  - max_transfer_seconds: Maximum seconds each transfer in the route can take (default: 2400)
    	  - max_n_transfers: Maximum number of transfers a route can contain (default: 20)
    	  - walkspeed_km_hr: Ratio of kilometers per hour the user walk (default: 4.5)
    	

Examples:
  Brussels Routing Example:
    mobroute route -p '{"route_params":{"feed_ids":[1088],"from":[50.85728,4.351426],"to":[50.83214,4.350534],"transfer_categories":["f","i"],"output_formats":["legs","diagnostics","mapurl","request"]}}'
  Krakow Routing Example:
    mobroute route -p '{"route_params":{"feed_ids":[1270],"from":[50.012338,19.88192],"to":[50.08785,20.02387],"transfer_categories":["f","i"],"output_formats":["legs","diagnostics","mapurl","request"]}}'
  NYC Routing Example:
    mobroute route -p '{"route_params":{"feed_ids":[516],"from":[40.70940,-74.00537],"to":[40.72879,-73.95215],"transfer_categories":["f","i"],"output_formats":["legs","diagnostics","mapurl","request"]}}'

```

## **Mobroute CLI: stops**
```
Usage of ./mobroute stops:

Description:
  TODO

Flags: 
  -d string
    	Verbose debug categories: (i) Information (w) Warn (d) Debug (default "i")
  -dprof string
    	Write debug pprof CPU profile to file
  -h	Show this usage message
  -p string
    	TODO

Examples:
  Krakow Stops Example:
    mobroute stops -p '{"stops_params": {"feed_ids": [1270]}}'
  NYC Stops Example:
    mobroute stops -p '{"stops_params": {"feed_ids": [516]}}'
  Brussels Stops Example:
    mobroute stops -p '{"stops_params": {"feed_ids": [1088]}}'

```

## **Mobroute CLI: schedule**
```
Usage of ./mobroute schedule:

Description:
  TODO

Flags: 
  -d string
    	Verbose debug categories: (i) Information (w) Warn (d) Debug (default "i")
  -dprof string
    	Write debug pprof CPU profile to file
  -h	Show this usage message
  -p string
    	TODO

Examples:
  Brussels Schedule Example:
    mobroute schedule -p '{"schedule_params": {"feed_ids": [1088], "stop_ids": ["1088_7225"], "max_seconds": 99999}}'
  Krakow Schedule Example:
    mobroute schedule -p '{"schedule_params": {"feed_ids": [1270], "stop_ids": ["1270_stop_293_61329"], "max_seconds": 99999}}'
  NYC Schedule Example:
    mobroute schedule -p '{"schedule_params": {"feed_ids": [516], "stop_ids": ["516_S30"], "max_seconds": 99999}}'

```

## **Mobroute CLI: database**
```
Usage of ./mobroute database:

Description:
  The database subcommand provides diagnostic functionality allowing you to alter the local SQLite database to import GTFS data (load), prepare routing optimizated tables (compute), and remove existing data (purge). This is essentially a passthrough to mobroute's underlying data ETL library mobsql.  After running database subcommands it's also helpful to query the database using the databaseq command for the effected feed IDs.

Flags: 
  -d string
    	Verbose debug categories: (i) Information (w) Warn (d) Debug (default "i")
  -dprof string
    	Write debug pprof CPU profile to file
  -h	Show this usage message
  -p string
    	
    	JSON Parameters for oneshot database subcommand, should be in format of: {"database_params": {"feed_ids": [767], "op": "load"}}
    	
    	Required database parameters:
    	  - feed_ids: Array of integer feed IDs (MDBID) to use for database requests (ex: [767])
    	  - op: Operation to perform - may be one of "load", "loadcustomgtfs", "compute", "purge_gtfs", "purge_computed", "purge_all" (ex: "load")
    	

Examples:
  Load a Custom GTFS Feed:
    mobroute database -p '{"database_params": {"op": "loadcustomgtfs", "feed_ids": [-33], "loadcustomgtfs_uri": "http://web.mta.info/developers/data/nyct/subway/google_transit.zip"}}'
  Compute Routing-Optimized GTFS Derived Tables:
    mobroute database -p '{"database_params": {"op": "compute", "feed_ids": [767]}}'
  Purge GTFS Feed Data:
    mobroute database -p '{"database_params": {"op": "purge_gtfs", "feed_ids": [767]}}'
  Purge Computed Tables:
    mobroute database -p '{"database_params": {"op": "purge_computed", "feed_ids": [767]}}'
  Purge All Tables:
    mobroute database -p '{"database_params": {"op": "purge_all", "feed_ids": [767]}}'
  Load a Mobility Database GTFS Feed:
    mobroute database -p '{"database_params": {"op": "load", "feed_ids": [767]}}'

```

## **Mobroute CLI: databaseq**
```
Usage of ./mobroute databaseq:

Description:
  The databaseq subcommand queries the underlying SQLite database to determine the loaded/computed status of particular GTFS feed IDs. This subcommand can be run after the database command (and before route, schedule, stops) commands to ensure data is loaded/computed. 	

Flags: 
  -d string
    	Verbose debug categories: (i) Information (w) Warn (d) Debug (default "i")
  -dprof string
    	Write debug pprof CPU profile to file
  -h	Show this usage message
  -p string
    	
    	JSON Parameters for oneshot database subcommand, should be in format of: {"database_params": {"feed_ids": [767], "op": "load"}}
    	
    	Required database parameters:
    	  - feed_ids: Array of integer feed IDs (MDBID) to use for database requests (ex: [767])
    	  - op: Operation to perform - may be one of "load", "loadcustomgtfs", "compute", "purge_gtfs", "purge_computed", "purge_all" (ex: "load")
    	

Examples:
  Determine the status of all GTFS feeds:
    mobroute databaseq -p '{"databaseq_params": {"feed_ids": []}}'
  Determine the status of single GTFS feed:
    mobroute databaseq -p '{"databaseq_params": {"feed_ids": [767]}}'

```


## **Further Resources & Documentation**

- [Automated Test Results / Metros](https://ci.lrdu.org/tests_results/): If you're curious about metros that have been well-tested and MDBIDs which you can experiment with for routing, this page has a number of working routing requests (lat/lon pairs and MDBIDs)
- [Development Guide](doc_dev.md): If you're curious about how Mobroute works under-the-hood, this guide can help architecture overview of what happens when you submit a routing request, from ETL, to algorithm, to formatting
- [Contribute Guide](doc_contribute.md): If you're intrested in contributing, this goes over the workflow.
- [Transito](http://git.sr.ht/~mil/transito): The Transito Mobile app runs the same routing logic the CLI executes on a mobile app (Android & Linux)

---

> [All Mobroute Docs](http://sr.ht/~mil/mobroute)
